..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

================
 Invenio-Config
================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-config.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-config

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-config.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-config

.. image:: https://img.shields.io/pypi/v/invenio-config.svg
        :target: https://pypi.org/pypi/invenio-config


Invenio configuration loader.

Invenio-Config is a base package of the Invenio digital library framework. It
is usually installed automatically as a dependency. It facilitates
configuration loading from various sources such as a Python module, an instance
folder or environment variables.

Further documentation is available on https://invenio-config.readthedocs.io/.
